@@ -18,6 +18,7 @@ from servicecatalog_puppet.workflow import manifest as manifest_tasks
 
 import logging
 
+
 logger = logging.getLogger("tasks")
 
 
@@ -1129,6 +1130,9 @@ class LaunchTask(ProvisioningTask):
 
         launch = manifest.get("launches").get(self.launch_name)
 
+        if not launch:
+            raise Exception(self.launch_name)
+
         configuration = manifest_utils_for_launches.get_configuration_from_launch(
             manifest, self.launch_name
         )
@@ -1144,20 +1148,56 @@ class LaunchTask(ProvisioningTask):
             self.puppet_account_id, False, self.launch_name, configuration, "launches"
         )
 
-        yield [
-            self.__class__(
-                launch_name=dependency,
-                manifest_file_path=self.manifest_file_path,
-                puppet_account_id=self.puppet_account_id,
-                should_use_sns=self.should_use_sns,
-                should_use_product_plans=self.should_use_product_plans,
-                include_expanded_from=self.include_expanded_from,
-                single_account=self.single_account,
-                is_dry_run=self.is_dry_run,
-                execution_mode=self.execution_mode,
-            )
-            for dependency in launch.get("depends_on", [])
-        ]
+        dependencies = list()
+        for dependency in launch.get("depends_on", []):
+            if isinstance(dependency, str):
+                dependencies.append(
+                    self.__class__(
+                        launch_name=dependency,
+                        manifest_file_path=self.manifest_file_path,
+                        puppet_account_id=self.puppet_account_id,
+                        should_use_sns=self.should_use_sns,
+                        should_use_product_plans=self.should_use_product_plans,
+                        include_expanded_from=self.include_expanded_from,
+                        single_account=self.single_account,
+                        is_dry_run=self.is_dry_run,
+                        execution_mode=self.execution_mode,
+                    )
+                )
+            else:
+                dependency_type = dependency.get("type", "launch")
+                if dependency_type == "launch":
+                    dependencies.append(
+                        self.__class__(
+                            launch_name=dependency,
+                            manifest_file_path=self.manifest_file_path,
+                            puppet_account_id=self.puppet_account_id,
+                            should_use_sns=self.should_use_sns,
+                            should_use_product_plans=self.should_use_product_plans,
+                            include_expanded_from=self.include_expanded_from,
+                            single_account=self.single_account,
+                            is_dry_run=self.is_dry_run,
+                            execution_mode=self.execution_mode,
+                        )
+                    )
+                elif dependency_type == "lambda-invocation":
+                    from servicecatalog_puppet.workflow.lambda_invocations import (
+                        LambdaInvocationTask,
+                    )
+
+                    dependencies.append(
+                        LambdaInvocationTask(
+                            lambda_invocation_name=dependency.get("name"),
+                            manifest_file_path=self.manifest_file_path,
+                            puppet_account_id=self.puppet_account_id,
+                            should_use_sns=self.should_use_sns,
+                            should_use_product_plans=self.should_use_product_plans,
+                            include_expanded_from=self.include_expanded_from,
+                            single_account=self.single_account,
+                            is_dry_run=self.is_dry_run,
+                        )
+                    )
+        yield dependencies
 
         logger.info(f"{self.uid} starting pre actions")
         pre_actions = manifest.get_actions_from(self.launch_name, "pre", "launches")
@@ -1204,7 +1244,7 @@ class SpokeLocalPortfolioTask(ProvisioningTask):
         }
 
     def requires(self):
-        logger.info("requires")
+        self.info("requires")
         dependencies = [
             LaunchTask(
                 launch_name=dependency,
@@ -1219,7 +1259,7 @@ class SpokeLocalPortfolioTask(ProvisioningTask):
             )
             for dependency in self.depends_on
         ]
-        logger.info(f"dependencies are {dependencies}")
+        self.info(f"dependencies are {dependencies}")
         return {
             "manifest": manifest_tasks.ManifestTask(
                 manifest_file_path=self.manifest_file_path,
